# tinicly

[![pypi](https://img.shields.io/pypi/v/tinicly.svg)](https://pypi.python.org/pypi/tinicly)
[![license](https://img.shields.io/github/license/samuelcolvin/tinicly.svg)](https://github.com/samuelcolvin/tinicly/blob/main/LICENSE)

CLI for tinifying images with <https://tinify.com/> and checking they're tinified.

## Usage

```bash
uvx tinicly --help
```
